@@ -1,6 +1,6 @@
 package Pcore::App::Redis;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::App::Alien];
 
@@ -21,7 +21,7 @@ sub cli_name ($self) {
 }
 
 sub _build_redis_ver ($self) {
-    return $self->cfg->{REDIS}->{REDIS_VER} || $PROC->{CFG}->{REDIS}->{REDIS_VER};
+    return $self->cfg->{REDIS}->{REDIS_VER} || $ENV->{CFG}->{REDIS}->{REDIS_VER};
 }
 
 # APP
@@ -32,7 +32,7 @@ around _build_cfg => sub ( $orig, $self ) {
         {   REDIS => {
                 SERVER => {
                     pidfile                     => $self->app_dir . 'redis.pid',
-                    port                        => 6379,                                             # use 0 to stop TCP interface
+                    port                        => 6379,                                            # use 0 to stop TCP interface
                     tcp_backlog                 => 511,
                     bind                        => [qw[127.0.0.1]],
                     unixsocket                  => q[/tmp/] . $self->name . q[.sock],
@@ -40,7 +40,7 @@ around _build_cfg => sub ( $orig, $self ) {
                     timeout                     => 0,
                     tcp_keepalive               => 0,
                     loglevel                    => 'notice',
-                    logfile                     => $PROC->{LOG_DIR} . $self->name . q[-redis.log],
+                    logfile                     => $ENV->{LOG_DIR} . $self->name . q[-redis.log],
                     databases                   => 16,
                     save                        => [ [ 900, 1 ], [ 300, 10 ], [ 60, 10_000 ], ],
                     stop_writes_on_bgsave_error => 'yes',
