@@ -1,6 +1,6 @@
-package Pcore::Redis v0.1.3;
+package Pcore::Redis v0.1.4;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 1;
 __END__
